#!/usr/bin/env node
"use strict";

var _fsExtra = _interopRequireDefault(require("fs-extra"));
var _path = _interopRequireDefault(require("path"));
var _child_process = require("child_process");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
const componentsDir = {
  TypographyDisplay: {
    folder: 'atom',
    component: 'typograph',
    file: 'Display.tsx'
  },
  TypographyHeading: {
    folder: 'atom',
    component: 'typograph',
    file: 'Heading.tsx'
  },
  TypographyParagraph: {
    folder: 'atom',
    component: 'typograph',
    file: 'Paragraph.tsx'
  },
  Button: {
    folder: 'molecule',
    component: 'button',
    file: 'Button.tsx'
  },
  TextButton: {
    folder: 'molecule',
    component: 'button',
    file: 'TextButton.tsx'
  },
  Input: {
    folder: 'molecule',
    component: 'form',
    file: 'Input.tsx',
    styleFile: 'Input.style.ts'
  },
  InputDate: {
    folder: 'molecule',
    component: 'form',
    file: 'InputDate.tsx'
  },
  InputOtp: {
    folder: 'molecule',
    component: 'form',
    file: 'InputOtp.tsx'
  },
  InputPhoneNumber: {
    folder: 'molecule',
    component: 'form',
    file: 'InputPhoneNumber.tsx',
    styleFile: 'Input.style.ts'
  },
  InputSelect: {
    folder: 'molecule',
    component: 'form',
    file: 'InputSelect.tsx'
  },
  Checkbox: {
    folder: 'molecule',
    component: 'form',
    file: 'Checkbox.tsx'
  },
  ToggleButton: {
    folder: 'molecule',
    component: 'form',
    file: 'ToggleButton.tsx'
  },
  BottomSheet: {
    folder: 'molecule',
    component: 'modals',
    file: 'BottomSheet.tsx'
  },
  PopupModal: {
    folder: 'molecule',
    component: 'modals',
    file: 'PopupModal.tsx'
  },
  Container: {
    folder: 'template',
    component: 'container',
    file: 'Container.tsx'
  }
};

// Get command-line arguments
const packageName = 'rn-adaptbyte';
const args = process.argv.slice(2);
const command = args[0];
const componentName = args[1];
if (!command || !componentsDir?.[componentName]) {
  console.log('Usage: npx my-cli add <package-name> <component-name>');
  process.exit(1);
}
const rootDir = process.cwd();
const adaptByteDir = _path.default.join(rootDir, 'src/adaptbyte');
const nodeModulesPath = _path.default.join(rootDir, 'node_modules', packageName, 'src', 'components', componentsDir?.[componentName]?.folder, componentsDir?.[componentName]?.component, componentsDir?.[componentName]?.file);
const targetComponentPath = _path.default.join(adaptByteDir, 'components', componentsDir?.[componentName]?.component, componentsDir?.[componentName]?.file);

// Replace @/ imports in the copied file
const replaceAliasImports = filePath => {
  if (!_fsExtra.default.existsSync(filePath)) return;
  let content = _fsExtra.default.readFileSync(filePath, 'utf8');
  // Match all import statements that are relative and NOT containing ".style"
  content = content.replace(/from\s+['"]((?:\.\/|\.\.\/)[^'"]*?)(?<!\.style)['"]/g, "from 'rn-adaptbyte'");
  _fsExtra.default.writeFileSync(filePath, content, 'utf8');
  console.log(`🔧 Replaced @/ imports in ${_path.default.basename(filePath)}`);
};

// Ensure adaptbyte folder exists
if (!_fsExtra.default.existsSync(adaptByteDir)) {
  console.log('Creating adaptbyte folder...');
  _fsExtra.default.mkdirSync(adaptByteDir);
}

// Install package if not found in node_modules
const packageInstalled = _fsExtra.default.existsSync(_path.default.join(rootDir, 'node_modules', packageName));
if (!packageInstalled) {
  console.log(`Installing ${packageName}...`);
  (0, _child_process.execSync)(`npm install ${packageName}`, {
    stdio: 'inherit'
  });
}

// Copy external file style
if (componentsDir?.[componentName]?.styleFile) {
  const nodeModulesStylePath = _path.default.join(rootDir, 'node_modules', packageName, 'src', 'components', componentsDir?.[componentName]?.folder, componentsDir?.[componentName]?.component, componentsDir?.[componentName]?.styleFile);
  const targetComponentStylePath = _path.default.join(adaptByteDir, 'components', componentsDir?.[componentName]?.component, componentsDir?.[componentName]?.styleFile);

  // Copy specific style if it exists
  if (_fsExtra.default.existsSync(nodeModulesStylePath)) {
    console.log(`Copying Style ${componentName} from ${packageName} to adaptbyte folder...`);
    _fsExtra.default.copySync(nodeModulesStylePath, targetComponentStylePath, {
      overwrite: true
    });
    console.log(`✅ Successfully copied  Style ${componentName} to adaptbyte/${componentName}`);
    replaceAliasImports(targetComponentStylePath);
  } else {
    console.error(`❌ Component Style ${componentName} not found in ${packageName}. Check if it exists in src/components.`);
    process.exit(1);
  }
}

// Copy specific component if it exists
if (_fsExtra.default.existsSync(nodeModulesPath)) {
  console.log(`Copying ${componentName} from ${packageName} to adaptbyte folder...`);
  _fsExtra.default.copySync(nodeModulesPath, targetComponentPath, {
    overwrite: true
  });
  console.log(`✅ Successfully copied ${componentName} to adaptbyte/${componentName}`);
  replaceAliasImports(targetComponentPath);
} else {
  console.error(`❌ Component ${componentName} not found in ${packageName}. Check if it exists in src/components.`);
  process.exit(1);
}
//# sourceMappingURL=index.js.map