"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _theme = require("../../../assets/theme.js");
var _index = require("../../atom/divider/index.js");
var _index2 = require("../../atom/index.js");
var _reactNativeUnistyles = require("react-native-unistyles");
var _reactNativeLinearGradient = _interopRequireDefault(require("react-native-linear-gradient"));
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
const Button = ({
  title,
  variant = 'large',
  mode = 'normal',
  flexGrow = 1,
  isLoading = false,
  loadingMessage = 'Loading',
  trailingIcon,
  leadingIcon,
  width = '100%',
  height = 'auto',
  colorText,
  disabled = false,
  onPress,
  spaceIcon = false,
  borderRadius = _theme.BORDERRADIUS.radius_40,
  backgroundColor,
  fontSize,
  style,
  contentStyle,
  linearGradientConfig,
  textConfig,
  borderColor,
  spaceIconH,
  spaceIconW,
  pressedStyle,
  // type = 'normal',
  ...props
}) => {
  const {
    styles,
    theme
  } = (0, _reactNativeUnistyles.useStyles)(stylesheet);
  backgroundColor = backgroundColor || theme.adaptbyte.colors.button.primary;
  const [isPressed, setIsPressed] = (0, _react.useState)(false);
  const borderColorOutlined = mode === 'outlined' && !borderColor ? theme.adaptbyte.colors.button.primary : borderColor;
  const styled = [styles.btn, {
    backgroundColor
  }, styles[`btn-${variant}`], {
    width,
    height
  }, styles[`btn-mode-${mode}`], isPressed ? pressedStyle || styles.btnPressed : null, isLoading ? styles.btnLoading : null, disabled ? styles[`btn-mode-disabled`] : null, {
    borderRadius,
    borderColorOutlined
  }];
  const textMode = () => {
    if (disabled) return 'disabled';
    return mode;
  };
  const textStyles = [styles.btnText, styles[`btn-text-${variant}`], styles[`btn-text-mode-${textMode()}`], textConfig?.color || colorText ? {
    color: isPressed ? theme.adaptbyte.colors.shade.white : textConfig?.color || colorText
  } : undefined, fontSize ? {
    fontSize
  } : undefined, spaceIconH || spaceIconW ? {
    marginHorizontal: undefined
  } : undefined];
  const gradientConfig = () => {
    if (_reactNative.Platform.OS === 'ios') {
      return {
        color: [theme.adaptbyte.colors.button.linearGradient.color1, theme.adaptbyte.colors.button.linearGradient.color2],
        location: [1, 0.1]
      };
    }
    return {
      color: [theme.adaptbyte.colors.button.linearGradient.color2, theme.adaptbyte.colors.button.linearGradient.color1],
      location: [0, 1]
    };
  };
  const renderContent = () => {
    const spaceSizeIcon = {
      flexGrow: !(spaceIconH || spaceIconW) ? flexGrow : undefined,
      height: spaceIconH,
      width: spaceIconW
    };
    return /*#__PURE__*/(0, _jsxRuntime.jsxs)(_jsxRuntime.Fragment, {
      children: [leadingIcon && spaceIcon && /*#__PURE__*/(0, _jsxRuntime.jsx)(_index.Spacer, {
        ...spaceSizeIcon
      }), leadingIcon && /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
        style: styles.iconContainer,
        children: leadingIcon
      }), (leadingIcon || trailingIcon) && spaceIcon && /*#__PURE__*/(0, _jsxRuntime.jsx)(_index.Spacer, {
        ...spaceSizeIcon
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_index2.Typography.Paragraph, {
        text: isLoading ? loadingMessage : title,
        weight: "bold",
        style: textStyles,
        align: "center",
        ...textConfig
      }), (leadingIcon || trailingIcon) && spaceIcon && /*#__PURE__*/(0, _jsxRuntime.jsx)(_index.Spacer, {
        ...spaceSizeIcon
      }), trailingIcon && /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
        style: styles.iconContainer,
        children: trailingIcon
      })]
    });
  };
  if (mode === 'linear-gradient' && !disabled) {
    return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Pressable, {
      onPress: onPress,
      style: [styles.containerGradient, style],
      onPressIn: () => setIsPressed(true),
      onPressOut: () => setIsPressed(false),
      disabled: isLoading || disabled,
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeLinearGradient.default, {
        colors: gradientConfig()?.color,
        start: {
          x: 0,
          y: 1
        },
        end: {
          x: 1,
          y: 1
        },
        style: [styles.btn, {
          borderRadius,
          opacity: isPressed ? 0.8 : 1
        }],
        locations: gradientConfig()?.location,
        ...linearGradientConfig,
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
          style: [styles[`btn-${variant}`], styles['btn-mode-linear-gradient'], contentStyle],
          children: renderContent()
        })
      })
    });
  }
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Pressable, {
    onPress: onPress,
    style: [styled, style],
    onPressIn: () => setIsPressed(true),
    onPressOut: () => setIsPressed(false),
    disabled: isLoading || disabled,
    ...props,
    children: renderContent()
  });
};
const stylesheet = (0, _reactNativeUnistyles.createStyleSheet)(theme => ({
  /**
   * Base
   */
  'containerGradient': {
    width: '100%'
  },
  'btn': {
    flexDirection: 'row',
    justifyContent: 'center',
    alignItems: 'center'
  },
  'btnText': {
    color: theme.adaptbyte.colors.primaryWhiteHex,
    marginHorizontal: theme.adaptbyte.spacing.space_8
  },
  'iconContainer': {
    marginRight: 2
  },
  /**
   * Button Variants
   */
  'btn-large': {
    paddingVertical: theme.adaptbyte.spacing.space_16,
    paddingHorizontal: theme.adaptbyte.spacing.space_32
  },
  'btn-medium': {
    paddingVertical: theme.adaptbyte.spacing.space_12,
    paddingHorizontal: theme.adaptbyte.spacing.space_24
  },
  'btn-small': {
    paddingVertical: theme.adaptbyte.spacing.space_8,
    paddingHorizontal: theme.adaptbyte.spacing.space_16
  },
  /**
   * Button text variant
   */
  'btn-text-large': {
    fontSize: theme.adaptbyte.typography.paragraph['text-03'].fontSize
  },
  'btn-text-medium': {
    fontSize: theme.adaptbyte.typography.paragraph['text-02'].fontSize
  },
  'btn-text-small': {
    fontSize: theme.adaptbyte.typography.paragraph['text-01'].fontSize
  },
  /**
   * Button state
   */
  'btnPressed': {
    backgroundColor: theme.adaptbyte.colors.primary._700
  },
  'btnLoading': {
    backgroundColor: theme.adaptbyte.colors.button.hover
  },
  'btnDisabled': {
    backgroundColor: theme.adaptbyte.colors.button.disabled
  },
  /**
   * Mode
   */
  'btn-mode-outlined': {
    backgroundColor: 'transparent',
    borderColor: theme.adaptbyte.colors.button.primary,
    borderWidth: 1
  },
  'btn-mode-normal': {},
  'btn-mode-disabled': {
    backgroundColor: theme.adaptbyte.colors.button.disabled
  },
  'btn-mode-light': {
    backgroundColor: 'transparent',
    borderWidth: 0
  },
  'btn-mode-red': {
    backgroundColor: theme.adaptbyte.colors.error._900,
    borderWidth: 0
  },
  'btn-mode-linear-gradient': {},
  /**
   * Text Color
   */
  'btn-text-mode-outlined': {
    color: theme.adaptbyte.colors.button.primary
  },
  'btn-text-mode-normal': {
    color: theme.adaptbyte.colors.button.textNormal
  },
  'btn-text-mode-disabled': {
    color: theme.adaptbyte.colors.button.textDisabled
  },
  'btn-text-mode-light': {
    color: theme.adaptbyte.colors.button.primary
  },
  'btn-text-mode-red': {
    color: theme.adaptbyte.colors.shade.white
  },
  'btn-text-mode-linear-gradient': {
    color: theme.adaptbyte.colors.button.textNormal
  }
}));
var _default = exports.default = Button;
//# sourceMappingURL=Button.js.map