"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _Ionicons = _interopRequireDefault(require("react-native-vector-icons/Ionicons"));
var _Octicons = _interopRequireDefault(require("react-native-vector-icons/Octicons"));
var _InputStyle = require("./Input.style.js");
var _theme = require("../../../assets/theme.js");
var _index = require("../../atom/index.js");
var _reactNativeUnistyles = require("react-native-unistyles");
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/* eslint-disable react-native/no-inline-styles */

/**
 * Component prop
 *
 * @interface InputProps
 * @typedef {InputProps}
 * @extends {TextInputProps}
 */

/**
 * Component
 * @param param0
 * @returns
 */const Input = ({
  keyboardType = 'default',
  variant = 'primary',
  type = 'normal',
  label,
  defaultValue,
  onChangeText,
  style,
  errorText,
  helperText,
  rightIcon,
  leftIcon,
  isPassword = false,
  disabled = false,
  outputRangeSize = 18,
  multiline,
  iIHeight,
  onPress = () => {},
  editable,
  isPressable,
  exLabelStyle,
  exTextInputStyle,
  width,
  placeholderTextColor,
  eyeIconColor,
  alertErrorIcon,
  exContainerStyle,
  ...props
}) => {
  /**
   * States
   */

  const {
    styles: inputStyles,
    theme
  } = (0, _reactNativeUnistyles.useStyles)(_InputStyle.inputStyles);
  const [isFocused, setIsFocused] = (0, _react.useState)(false);
  const [animatedIsFocused] = (0, _react.useState)(new _reactNative.Animated.Value(defaultValue ? 1 : 0));
  const [text, setText] = (0, _react.useState)('');
  const [isPasswordVisible, setIsPasswordVisible] = (0, _react.useState)(false);
  iIHeight = iIHeight ?? theme.adaptbyte.length.length_38;

  /**
   * useEffects
   */
  (0, _react.useEffect)(() => {
    if (defaultValue) {
      setText(defaultValue);
    } else {
      setText('');
    }
  }, [defaultValue]);
  (0, _react.useEffect)(() => {
    _reactNative.Animated.timing(animatedIsFocused, {
      toValue: isFocused || text ? 1 : 0,
      duration: 200,
      useNativeDriver: false
    }).start();
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [isFocused, text]);

  /**
   * Handle text change
   */
  const handleTextChange = val => {
    if (/^\s*$/.test(val)) {
      setText('');
      if (onChangeText) onChangeText('');
    } else {
      setText(val);
      if (onChangeText) onChangeText(val);
    }
  };
  const togglePasswordVisibility = () => {
    setIsPasswordVisible(!isPasswordVisible);
  };

  // Container Style
  const containerStyle = () => {
    const staticStyle = {
      width
    };
    const container = [inputStyles.container, (0, _InputStyle.inputVariantStyle)(theme)?.[variant]?.container, staticStyle];
    if (errorText && disabled) {
      container.push((0, _InputStyle.inputVariantStyle)(theme)?.[variant]?.errorDisabledContainer);
    } else if (disabled) {
      container.push((0, _InputStyle.inputVariantStyle)(theme)?.[variant]?.disabledContainer);
    } else if (errorText) {
      container.push((0, _InputStyle.inputVariantStyle)(theme)?.[variant]?.errorContainer);
    }
    if (multiline) {
      container.push({
        height: 'auto'
      });
    }
    if (style) {
      container.push(style);
    }
    return container;
  };

  //InputStyle
  const inputStyle = () => {
    const input = [inputStyles.input, (0, _InputStyle.inputVariantStyle)(theme)?.[variant]?.input, {
      fontFamily: theme.adaptbyte.font.normal.regular
    }];
    let color = (0, _InputStyle.inputVariantStyle)(theme)?.[variant]?.input?.color;
    if (errorText && disabled) {
      color = theme.adaptbyte.colors.error._500;
    } else if (errorText) {
      color = theme.adaptbyte.colors.danger;
    } else if (disabled) {
      color = (0, _InputStyle.inputVariantStyle)(theme)?.[variant]?.disabledInput?.color;
    }
    input.push({
      color
    });
    if (leftIcon) {
      input.push({
        left: _theme.SPACING.space_16
      });
    }
    if (rightIcon) {
      const contentWidth = width ?? _theme.WIDTH_WINDOW;
      const spacing = width ? _theme.SPACING.space_72 : _theme.SPACING.space_120;
      input.push({
        width: contentWidth - spacing
      });
    }
    if (multiline) {
      input.push({
        height: 'auto'
      });
    }
    if (exTextInputStyle) {
      input.push(exTextInputStyle);
    }
    return input;
  };
  const labelStyle = () => {
    const animatedTop = type !== 'table' ? animatedIsFocused.interpolate({
      inputRange: [0, 1],
      outputRange: [outputRangeSize, 8]
    }) : outputRangeSize;
    const animatedFontSize = type !== 'table' ? animatedIsFocused.interpolate({
      inputRange: [0, 1],
      outputRange: [14, 12]
    }) : 14;
    const animated = {
      position: 'absolute',
      left: 16,
      right: 16,
      display: type === 'table' && text?.length ? 'none' : undefined,
      top: animatedTop,
      fontSize: animatedFontSize,
      fontFamily: theme.adaptbyte.font.normal.regular
    };
    const labels = [inputStyles.label, (0, _InputStyle.inputVariantStyle)(theme)?.[variant]?.label, animated];
    let color = (0, _InputStyle.inputVariantStyle)(theme)?.[variant]?.label?.color;
    if (!isFocused && !text?.length && errorText?.length) {
      color = theme.adaptbyte.colors.danger;
    }
    if (leftIcon) {
      labels.push({
        marginLeft: 27
      });
    }
    labels.push({
      color
    });
    if (exLabelStyle) {
      labels.push(exLabelStyle);
    }
    return labels;
  };
  function renderTextInput() {
    if (isPressable) {
      return /*#__PURE__*/(0, _jsxRuntime.jsx)(_index.Typography.Paragraph, {
        text: text,
        style: inputStyle()
      });
    }
    return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.TextInput, {
      keyboardType: keyboardType,
      editable: editable !== undefined ? editable : !disabled,
      returnKeyType: _reactNative.Platform.OS === 'ios' ? 'done' : 'next',
      defaultValue: defaultValue,
      multiline: multiline,
      style: inputStyle(),
      onChangeText: handleTextChange,
      onFocus: () => setIsFocused(true),
      onBlur: () => setIsFocused(false),
      secureTextEntry: isPassword && !isPasswordVisible,
      placeholderTextColor: placeholderTextColor ?? (0, _InputStyle.inputVariantStyle)(theme)?.[variant]?.label?.color,
      ...props
    });
  }

  /**
   * Return
   */

  return /*#__PURE__*/(0, _jsxRuntime.jsxs)(_reactNative.View, {
    style: [exContainerStyle],
    children: [/*#__PURE__*/(0, _jsxRuntime.jsxs)(_reactNative.TouchableOpacity, {
      activeOpacity: isPressable && !disabled ? 0 : 1,
      onPress: disabled ? () => {} : onPress,
      style: containerStyle(),
      children: [!!label?.length && /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Animated.Text, {
        style: labelStyle(),
        children: label
      }), /*#__PURE__*/(0, _jsxRuntime.jsxs)(_reactNative.View, {
        style: [inputStyles.innerInputContainer],
        children: [leftIcon && /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
          style: inputStyles.leftIconContainer,
          children: leftIcon
        }), /*#__PURE__*/(0, _jsxRuntime.jsxs)(_reactNative.View, {
          style: [inputStyles.innerInput, {
            height: iIHeight,
            minHeight: iIHeight
          }, !label && {
            justifyContent: 'center',
            height: 'auto'
          }, multiline && {
            height: 'auto'
          }],
          children: [label && /*#__PURE__*/(0, _jsxRuntime.jsx)(_index.Spacer, {
            height: type === 'table' ? 9 : 17
          }), renderTextInput()]
        }), isPassword && /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.TouchableOpacity, {
          onPress: togglePasswordVisibility,
          style: inputStyles.iconContainer,
          children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_Octicons.default, {
            name: isPasswordVisible ? 'eye' : 'eye-closed',
            size: 18,
            color: eyeIconColor ?? (0, _InputStyle.inputVariantStyle)(theme)?.[variant]?.input?.color
          })
        }), rightIcon && /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
          style: inputStyles.rightIconContainer,
          children: rightIcon
        })]
      })]
    }), errorText || helperText ? /*#__PURE__*/(0, _jsxRuntime.jsxs)(_reactNative.View, {
      style: inputStyles.helperContainer,
      children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
        style: inputStyles.helperIcon,
        children: errorText && (alertErrorIcon ?? /*#__PURE__*/(0, _jsxRuntime.jsx)(_Ionicons.default, {
          name: "alert-circle",
          size: 16,
          color: theme.adaptbyte.colors.error._700
        }))
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
        style: inputStyles.helperMessage,
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_index.Typography.Paragraph, {
          variant: "00",
          weight: "regular",
          text: errorText ? errorText : helperText ?? '',
          color: errorText ? theme.adaptbyte.colors.error._500 : (0, _InputStyle.inputVariantStyle)(theme)?.[variant]?.label?.color
        })
      })]
    }) : null]
  });
};

/**
 * Export
 */
var _default = exports.default = Input;
//# sourceMappingURL=Input.js.map