"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _theme = require("../../../assets/theme.js");
var _reactNativeUnistyles = require("react-native-unistyles");
var _index = require("../../atom/index.js");
var _Ionicons = _interopRequireDefault(require("react-native-vector-icons/Ionicons"));
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
const InputOtp = ({
  onChangeText,
  style,
  exInputStyle,
  otpLength = 4,
  defaultOtp,
  errorText,
  errorIcon
}) => {
  const [otp, setOTP] = (0, _react.useState)(Array(otpLength).fill(''));
  const refs = (0, _react.useRef)([]);
  const {
    styles,
    theme
  } = (0, _reactNativeUnistyles.useStyles)(stylesheet);

  // Set Default Otp
  (0, _react.useEffect)(() => {
    if (defaultOtp?.length === otpLength) {
      setOTP(defaultOtp);
    }
  }, [defaultOtp, otpLength]);
  const handleOTPChange = (index, value) => {
    // Allow only numeric values
    if (value !== '' && isNaN(Number(value))) return;
    let newOTP = [...otp];
    if (value?.length > 1) {
      newOTP = [...otp];
      if (index + 1 !== otpLength) {
        newOTP[index + 1] = value?.charAt(1);
      }
      setOTP(newOTP);
      return refs.current[index + 1]?.focus();
    } else {
      newOTP = [...otp];
      newOTP[index] = value;
      setOTP(newOTP);
    }

    // Move focus to the next input if a number is entered
    if (value !== '' && index < otpLength - 1) {
      refs.current[index + 1]?.focus();
    } else if (value === '' && index > 0) {
      // Move focus to the previous input if input is cleared
      refs.current[index - 1]?.focus();
    }
    onChangeText ? onChangeText(newOTP.join('')) : null;
  };
  const handleKeyPress = (index, key) => {
    // Detect backspace key press
    if (key === 'Backspace' && otp[index] === '' && index > 0) {
      refs.current[index - 1]?.focus();
    }
  };
  return /*#__PURE__*/(0, _jsxRuntime.jsxs)(_reactNative.View, {
    children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
      style: [styles.container, style],
      children: Array.from({
        length: otpLength
      }).map((_, index) => /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.TextInput, {
        ref: el => refs.current[index] = el // Assign ref
        ,
        style: [styles.input, {
          borderColor: errorText?.length ? theme.adaptbyte.colors.error._700 : theme.adaptbyte.colors.grayscale._200
        }, exInputStyle],
        returnKeyType: _reactNative.Platform.OS === 'ios' ? 'done' : 'next',
        keyboardType: "numeric",
        value: otp[index],
        onChangeText: value => handleOTPChange(index, value),
        onKeyPress: ({
          nativeEvent
        }) => handleKeyPress(index, nativeEvent.key)
      }, index))
    }), !!errorText?.length && /*#__PURE__*/(0, _jsxRuntime.jsxs)(_reactNative.View, {
      style: styles.errorContainer,
      children: [errorIcon ?? /*#__PURE__*/(0, _jsxRuntime.jsx)(_Ionicons.default, {
        name: "alert-circle",
        size: 16,
        color: theme.adaptbyte.colors.error._700
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_index.Typography.Paragraph, {
        variant: "00",
        weight: "medium",
        text: errorText,
        color: theme.adaptbyte.colors.error._500
      })]
    })]
  });
};
const stylesheet = (0, _reactNativeUnistyles.createStyleSheet)(theme => ({
  container: {
    flexDirection: 'row',
    justifyContent: 'space-between',
    alignItems: 'center',
    marginTop: theme.adaptbyte.spacing.space_16
  },
  errorContainer: {
    alignSelf: 'center',
    marginTop: theme.adaptbyte.spacing.space_16,
    flexDirection: 'row',
    gap: theme.adaptbyte.spacing.space_10
  },
  input: {
    height: theme.adaptbyte.length.length_80,
    width: theme.adaptbyte.length.length_72,
    borderWidth: 1,
    marginHorizontal: theme.adaptbyte.spacing.space_5,
    textAlign: 'center',
    borderRadius: theme.adaptbyte.length.length_8,
    backgroundColor: theme.adaptbyte.colors.grayscale._50,
    fontSize: theme.adaptbyte.length.length_48,
    color: theme.adaptbyte.colors.shade.black,
    fontFamily: _theme.FONTFAMILY.PlusJakartaSans_medium
  }
}));
var _default = exports.default = InputOtp;
//# sourceMappingURL=InputOtp.js.map