"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireDefault(require("react"));
var _reactNative = require("react-native");
var _reactNativeSafeAreaContext = require("react-native-safe-area-context");
var _index = require("../../atom/index.js");
var _theme = require("../../../assets/theme.js");
var _reactNativeUnistyles = require("react-native-unistyles");
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
const statusBarHeight = _reactNative.StatusBar.currentHeight ?? 0;
/**
 * Container prop
 *
 * @interface ContainerProps
 * @typedef {ContainerProps}
 * @extends {SafeAreaViewProps}
 */

/**
 * Container
 *
 * @param {ContainerProps} param0
 * @param {*} param0.children
 * @param {*} param0.style
 * @param {StatusBarStyle} [param0.barStyle="default"]
 * @param {ColorValue} [param0.barBackgroundColor="transparent"]
 * @returns {*}
 */
const Container = ({
  children,
  style,
  barStyle = 'dark-content',
  barBackgroundColor,
  isKeyboardAvoiding = false,
  backgroundColor,
  edges = ['top', 'bottom'],
  barHidden = false,
  FooterComponent,
  headerConfig = {},
  exContentStyle,
  isHeader
}) => {
  const {
    styles,
    theme
  } = (0, _reactNativeUnistyles.useStyles)(stylesheet);
  backgroundColor = backgroundColor ?? theme.adaptbyte.colors.primaryWhiteHex;
  barBackgroundColor = barBackgroundColor ?? theme.adaptbyte.colors.primaryWhiteHex;
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeSafeAreaContext.SafeAreaProvider, {
    children: /*#__PURE__*/(0, _jsxRuntime.jsxs)(_reactNativeSafeAreaContext.SafeAreaView, {
      style: [style, styles.container, {
        backgroundColor: barBackgroundColor
      }],
      edges: edges,
      children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.StatusBar, {
        translucent: true,
        backgroundColor: barBackgroundColor,
        barStyle: barStyle,
        hidden: barHidden
      }), isHeader && /*#__PURE__*/(0, _jsxRuntime.jsx)(_index.Header, {
        ...headerConfig
      }), isKeyboardAvoiding ? /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.KeyboardAvoidingView, {
        style: [styles.wrapper, exContentStyle, {
          backgroundColor
        }],
        enabled: isKeyboardAvoiding,
        behavior: _reactNative.Platform.OS === 'ios' ? 'padding' : 'height',
        keyboardVerticalOffset: _reactNative.Platform.OS === 'ios' ? statusBarHeight + _theme.SPACING.space_12 : 0,
        children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.ScrollView, {
          showsVerticalScrollIndicator: false,
          contentContainerStyle: styles.scrollView,
          children: children
        })
      }) : /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
        style: [styles.wrapper, exContentStyle, {
          backgroundColor
        }],
        children: children
      }), FooterComponent && /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
        style: {
          backgroundColor
        },
        children: typeof FooterComponent === 'function' ? /*#__PURE__*/(0, _jsxRuntime.jsx)(FooterComponent, {}) : FooterComponent
      })]
    })
  });
};

/**
 * Stylesheet
 *
 * @type {*}
 */
const stylesheet = (0, _reactNativeUnistyles.createStyleSheet)(theme => ({
  container: {
    flexGrow: 1
  },
  wrapper: {
    paddingTop: theme.adaptbyte.spacing.container.space_top,
    paddingBottom: theme.adaptbyte.spacing.container.space_bottom,
    paddingHorizontal: theme.adaptbyte.spacing.container.space_horizontal,
    flex: 1
  },
  scrollView: {
    flexGrow: 1
  }
}));

/**
 * Export container
 */
var _default = exports.default = Container;
//# sourceMappingURL=Container.js.map