"use strict";

import React from 'react';
import { StyleSheet, Pressable } from 'react-native';
import { Typography } from "../../atom/index.js";
import { createStyleSheet, useStyles } from 'react-native-unistyles';
import { jsx as _jsx } from "react/jsx-runtime";
const TextButton = ({
  title,
  size = 'default',
  underline,
  weight = 'bold',
  textColor,
  disabled,
  onPress,
  style,
  fontSize,
  textConfig,
  ...props
}) => {
  const {
    styles,
    theme
  } = useStyles(stylesheet);
  const textStyle = StyleSheet.flatten([fontSize ? {
    fontSize
  } : styles[`text-size-${size}`], styles[`text-weight-${weight}`], underline && {
    textDecorationLine: 'underline'
  }, {
    color: disabled ? theme.adaptbyte.colors.link.disabled : textColor ?? theme.adaptbyte.colors.button.primary
  }]);
  return /*#__PURE__*/_jsx(Pressable, {
    onPress: onPress,
    disabled: disabled,
    style: ({
      pressed
    }) => [styles.container, pressed && {
      opacity: 0.5
    }, style],
    ...props,
    children: /*#__PURE__*/_jsx(Typography.Paragraph, {
      style: textStyle,
      text: title,
      ...textConfig
    })
  });
};
export default TextButton;
const stylesheet = createStyleSheet(theme => ({
  'container': {
    flexDirection: 'row',
    justifyContent: 'center',
    alignItems: 'center'
  },
  'text-weight-bold': {
    fontFamily: theme.adaptbyte.font.normal.bold
  },
  'text-weight-medium': {
    fontFamily: theme.adaptbyte.font.normal.medium
  },
  'text-size-small': {
    fontSize: theme.adaptbyte.typography.paragraph['text-02'].fontSize
  },
  'text-size-default': {
    fontSize: theme.adaptbyte.typography.paragraph['text-03'].fontSize
  }
}));
//# sourceMappingURL=TextButton.js.map