"use strict";

import React, { useEffect, useState } from 'react';
import { Input } from "../form/index.js";
import Feather from 'react-native-vector-icons/Feather';
import { View } from 'react-native';
import { SPACING } from "../../../assets/theme.js";
import { Button } from "../button/index.js";
import { CalendarPicker, TimeslotPicker } from "../picker/index.js";
import { Paragraph, Spacer } from "../../atom/index.js";
import { BottomSheet } from "../modals/index.js";
import { useStyles } from 'react-native-unistyles';

/**
 * Component prop
 *
 * @interface InputDateProps
 * @typedef {InputDateProps}
 * @extends {InputProps}
 */

/**
 * Component
 * @param param0
 * @returns
 */
import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
const DateBottomSheet = ({
  onSelectDate = () => {},
  onSelectTimeslot,
  selectedDate,
  selectedTimeSlot,
  isUseTimeSlot,
  isUsePickerDate = true,
  calendarConfig,
  timeslotConfig = {
    slots: ['08:00AM - 12:00PM', '02:00PM - 05:00PM']
  },
  submitText = 'Continue',
  onSubmit
}) => {
  const [date, setDate] = useState(selectedDate);
  const [slot, setSlot] = useState(undefined);
  return /*#__PURE__*/_jsxs(View, {
    children: [isUsePickerDate && /*#__PURE__*/_jsxs(View, {
      children: [/*#__PURE__*/_jsx(CalendarPicker, {
        dateValue: selectedDate ?? '',
        onDateChange: setDate,
        ...calendarConfig
      }), /*#__PURE__*/_jsx(Spacer, {
        height: SPACING.space_16
      })]
    }), isUseTimeSlot && /*#__PURE__*/_jsxs(View, {
      children: [/*#__PURE__*/_jsx(Paragraph, {
        weight: "bold",
        variant: "02",
        text: "Time Slot"
      }), /*#__PURE__*/_jsx(Spacer, {
        height: SPACING.space_16
      }), /*#__PURE__*/_jsx(TimeslotPicker, {
        selectedSlot: selectedTimeSlot,
        onSelect: setSlot,
        ...timeslotConfig
      })]
    }), /*#__PURE__*/_jsx(Spacer, {
      height: SPACING.space_12
    }), /*#__PURE__*/_jsx(Button, {
      disabled: false,
      title: submitText,
      onPress: () => {
        if (typeof onSelectDate === 'function') {
          onSelectDate(date);
        }
        if (typeof onSelectTimeslot === 'function') {
          onSelectTimeslot(slot);
        }
        if (typeof onSubmit === 'function') {
          onSubmit();
        }
      }
    })]
  });
};
function InputDate({
  defaultBottomSheetVisible,
  dateValue,
  title,
  config,
  ...props
}) {
  const [isBottomSheetVisible, setBottomSheetVisible] = useState(false);
  const {
    theme
  } = useStyles();
  useEffect(() => {
    if (typeof defaultBottomSheetVisible === 'boolean') {
      setBottomSheetVisible(defaultBottomSheetVisible);
    }
  }, [defaultBottomSheetVisible]);
  return /*#__PURE__*/_jsxs(_Fragment, {
    children: [/*#__PURE__*/_jsx(Input, {
      defaultValue: dateValue,
      isPressable: true,
      onPress: () => setBottomSheetVisible(!isBottomSheetVisible),
      rightIcon: /*#__PURE__*/_jsx(Feather, {
        name: "calendar",
        color: theme.adaptbyte.colors.grayscale._500,
        size: theme.adaptbyte.length.length_20
      }),
      ...props
    }), /*#__PURE__*/_jsx(BottomSheet, {
      isVisible: isBottomSheetVisible,
      title: title,
      onClosePress: () => setBottomSheetVisible(false),
      children: /*#__PURE__*/_jsx(DateBottomSheet, {
        ...config,
        onSubmit: () => {
          config?.onSubmit?.();
          setBottomSheetVisible(false);
        }
      })
    })]
  });
}
export default InputDate;
//# sourceMappingURL=InputDate.js.map