"use strict";

import React, { useState, useRef, useEffect } from 'react';
import { TextInput, View, Platform } from 'react-native';
import { FONTFAMILY } from "../../../assets/theme.js";
import { createStyleSheet, useStyles } from 'react-native-unistyles';
import { Typography } from "../../atom/index.js";
import Icon from 'react-native-vector-icons/Ionicons';
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
const InputOtp = ({
  onChangeText,
  style,
  exInputStyle,
  otpLength = 4,
  defaultOtp,
  errorText,
  errorIcon
}) => {
  const [otp, setOTP] = useState(Array(otpLength).fill(''));
  const refs = useRef([]);
  const {
    styles,
    theme
  } = useStyles(stylesheet);

  // Set Default Otp
  useEffect(() => {
    if (defaultOtp?.length === otpLength) {
      setOTP(defaultOtp);
    }
  }, [defaultOtp, otpLength]);
  const handleOTPChange = (index, value) => {
    // Allow only numeric values
    if (value !== '' && isNaN(Number(value))) return;
    let newOTP = [...otp];
    if (value?.length > 1) {
      newOTP = [...otp];
      if (index + 1 !== otpLength) {
        newOTP[index + 1] = value?.charAt(1);
      }
      setOTP(newOTP);
      return refs.current[index + 1]?.focus();
    } else {
      newOTP = [...otp];
      newOTP[index] = value;
      setOTP(newOTP);
    }

    // Move focus to the next input if a number is entered
    if (value !== '' && index < otpLength - 1) {
      refs.current[index + 1]?.focus();
    } else if (value === '' && index > 0) {
      // Move focus to the previous input if input is cleared
      refs.current[index - 1]?.focus();
    }
    onChangeText ? onChangeText(newOTP.join('')) : null;
  };
  const handleKeyPress = (index, key) => {
    // Detect backspace key press
    if (key === 'Backspace' && otp[index] === '' && index > 0) {
      refs.current[index - 1]?.focus();
    }
  };
  return /*#__PURE__*/_jsxs(View, {
    children: [/*#__PURE__*/_jsx(View, {
      style: [styles.container, style],
      children: Array.from({
        length: otpLength
      }).map((_, index) => /*#__PURE__*/_jsx(TextInput, {
        ref: el => refs.current[index] = el // Assign ref
        ,
        style: [styles.input, {
          borderColor: errorText?.length ? theme.adaptbyte.colors.error._700 : theme.adaptbyte.colors.grayscale._200
        }, exInputStyle],
        returnKeyType: Platform.OS === 'ios' ? 'done' : 'next',
        keyboardType: "numeric",
        value: otp[index],
        onChangeText: value => handleOTPChange(index, value),
        onKeyPress: ({
          nativeEvent
        }) => handleKeyPress(index, nativeEvent.key)
      }, index))
    }), !!errorText?.length && /*#__PURE__*/_jsxs(View, {
      style: styles.errorContainer,
      children: [errorIcon ?? /*#__PURE__*/_jsx(Icon, {
        name: "alert-circle",
        size: 16,
        color: theme.adaptbyte.colors.error._700
      }), /*#__PURE__*/_jsx(Typography.Paragraph, {
        variant: "00",
        weight: "medium",
        text: errorText,
        color: theme.adaptbyte.colors.error._500
      })]
    })]
  });
};
const stylesheet = createStyleSheet(theme => ({
  container: {
    flexDirection: 'row',
    justifyContent: 'space-between',
    alignItems: 'center',
    marginTop: theme.adaptbyte.spacing.space_16
  },
  errorContainer: {
    alignSelf: 'center',
    marginTop: theme.adaptbyte.spacing.space_16,
    flexDirection: 'row',
    gap: theme.adaptbyte.spacing.space_10
  },
  input: {
    height: theme.adaptbyte.length.length_80,
    width: theme.adaptbyte.length.length_72,
    borderWidth: 1,
    marginHorizontal: theme.adaptbyte.spacing.space_5,
    textAlign: 'center',
    borderRadius: theme.adaptbyte.length.length_8,
    backgroundColor: theme.adaptbyte.colors.grayscale._50,
    fontSize: theme.adaptbyte.length.length_48,
    color: theme.adaptbyte.colors.shade.black,
    fontFamily: FONTFAMILY.PlusJakartaSans_medium
  }
}));
export default InputOtp;
//# sourceMappingURL=InputOtp.js.map