"use strict";

import { View, Image, TouchableOpacity } from 'react-native';
import React, { useState } from 'react';
import FontAwesome5 from 'react-native-vector-icons/FontAwesome';
import { LENGTH, SPACING } from "../../../assets/theme.js";
import { inputVariantStyle } from "./Input.style.js";
import { Line, Paragraph, Spacer } from "../../atom/index.js";
import { Input } from "../form/index.js";
import { createStyleSheet, useStyles } from 'react-native-unistyles';
/**
 *
 * @param {InputPhoneNumberProps}
 * @returns
 */
import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
const InputPhoneNumber = ({
  onChangeText,
  onBlur,
  onPressCountry,
  chevronDownColor,
  phoneNumberRegex = /^[1-9][0-9]{7,9}$/,
  countryImg = /*#__PURE__*/_jsx(Image, {
    style: {
      width: LENGTH.length_24,
      height: LENGTH.length_16
    },
    source: require('../../../assets/image/webp/malaysia_flag.webp')
  }),
  phoneCodeConfig = {
    text: '+60'
  },
  placeholder = 'Phone Number',
  exTextInputStyle = {},
  variant = 'transparent',
  style = {},
  isArrowDown,
  maxLength = 13,
  ...props
}) => {
  const [phoneNumber, setPhoneNumber] = useState('');
  const {
    styles,
    theme
  } = useStyles(stylesheet);
  const leftIcon = /*#__PURE__*/_jsxs(View, {
    style: styles.leftIconContainer,
    children: [/*#__PURE__*/_jsxs(TouchableOpacity, {
      style: styles.leftIconButton,
      onPress: onPressCountry,
      disabled: true,
      children: [countryImg, /*#__PURE__*/_jsx(Spacer, {
        width: SPACING.space_8
      }), isArrowDown && /*#__PURE__*/_jsx(_Fragment, {
        children: /*#__PURE__*/_jsx(FontAwesome5, {
          name: "chevron-down",
          color: chevronDownColor ?? inputVariantStyle(theme)?.[variant]?.input?.color
        })
      }), /*#__PURE__*/_jsx(Spacer, {
        width: SPACING.space_12
      })]
    }), /*#__PURE__*/_jsx(Line, {
      orientation: "vertical",
      length: LENGTH.length_42
    }), /*#__PURE__*/_jsx(Spacer, {
      width: SPACING.space_12
    }), /*#__PURE__*/_jsx(Paragraph, {
      variant: "01",
      weight: "extrabold",
      text: phoneCodeConfig?.text,
      color: phoneCodeConfig?.color ?? inputVariantStyle(theme)?.[variant]?.input?.color,
      ...phoneCodeConfig
    }), /*#__PURE__*/_jsx(Spacer, {
      width: SPACING.space_8
    })]
  });
  const onChangePhoneNumber = text => {
    setPhoneNumber(text);
    onChangeText?.(text);
  };
  const onPhoneNumberBlur = () => {
    if (!phoneNumberRegex.test(phoneNumber)) {
      onBlur?.({
        error: 'invalidPhone'
      });
    } else {
      onBlur?.();
    }
  };
  return /*#__PURE__*/_jsx(Input, {
    type: "table",
    keyboardType: 'phone-pad',
    style: [styles.style, style],
    maxLength: maxLength,
    onChangeText: onChangePhoneNumber,
    onBlur: onPhoneNumberBlur,
    leftIcon: leftIcon,
    placeholder: placeholder,
    exTextInputStyle: [styles.exTextInputStyle, exTextInputStyle],
    variant: variant,
    ...props
  });
};
const stylesheet = createStyleSheet(() => ({
  leftIconContainer: {
    flexDirection: 'row',
    alignItems: 'center',
    height: '100%'
  },
  leftIconButton: {
    height: '100%',
    alignItems: 'center',
    flexDirection: 'row'
  },
  style: {
    justifyContent: 'center'
  },
  exTextInputStyle: {
    left: 0
  }
}));
export default InputPhoneNumber;
//# sourceMappingURL=InputPhoneNumber.js.map