"use strict";

import React, { useEffect, useState } from 'react';
import { Input } from "../form/index.js";
import FontAwesome5Icon from 'react-native-vector-icons/FontAwesome5';
import { BottomSheet, PopupModal } from "../modals/index.js";
import { useStyles } from 'react-native-unistyles';
import { View } from 'react-native';
import { Typography } from "../../atom/index.js";

/**
 * Component prop
 *
 * @interface InputSelectProps
 * @typedef {InputSelectProps}
 * @extends {InputProps}
 */

/**
 * Component
 * @param param0
 * @returns
 */
import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
function InputSelect({
  onSelect,
  listData = [],
  value,
  defaultOptionVisible,
  modalType,
  renderItem,
  modalTitle,
  titleConfig,
  bottomsheetConfig,
  popupModalConfig,
  exItemsContainerStyle,
  ...props
}) {
  const [isOptionVisible, setOptionVisible] = useState(false);
  const {
    theme
  } = useStyles();
  useEffect(() => {
    if (typeof defaultOptionVisible === 'boolean') {
      setOptionVisible(defaultOptionVisible);
    }
  }, [defaultOptionVisible]);
  const renderItems = () => {
    return listData?.map(item => renderItem ? renderItem(item) : /*#__PURE__*/_jsx(Typography.Paragraph, {
      onPress: () => {
        onSelect(item);
        setOptionVisible(false);
      },
      weight: "medium",
      style: {
        marginBottom: theme.adaptbyte.spacing.space_20
      },
      text: item?.name
    }, item?.name));
  };
  return /*#__PURE__*/_jsxs(_Fragment, {
    children: [/*#__PURE__*/_jsx(Input, {
      defaultValue: value,
      isPressable: true,
      onPress: () => setOptionVisible(!isOptionVisible),
      rightIcon: /*#__PURE__*/_jsx(FontAwesome5Icon, {
        name: "chevron-down",
        color: theme.adaptbyte.colors.grayscale._500,
        size: theme.adaptbyte.length.length_20
      }),
      ...props
    }), modalType === 'bottomsheet' ? /*#__PURE__*/_jsx(BottomSheet, {
      onClosePress: () => setOptionVisible(false),
      title: modalTitle,
      isVisible: isOptionVisible,
      titleConfig: titleConfig,
      ...bottomsheetConfig,
      children: /*#__PURE__*/_jsx(View, {
        style: [{
          marginTop: theme.adaptbyte.spacing.space_30
        }, exItemsContainerStyle],
        children: renderItems()
      })
    }) : /*#__PURE__*/_jsxs(PopupModal, {
      onBackdropPress: () => setOptionVisible(false),
      isVisible: isOptionVisible,
      ...popupModalConfig,
      children: [!!modalTitle && /*#__PURE__*/_jsx(Typography.Paragraph, {
        variant: "03",
        text: modalTitle,
        weight: "bold",
        ...titleConfig
      }), /*#__PURE__*/_jsx(View, {
        style: [{
          marginTop: theme.adaptbyte.spacing.space_30
        }, exItemsContainerStyle],
        children: renderItems()
      })]
    })]
  });
}
export default InputSelect;
//# sourceMappingURL=InputSelect.js.map