"use strict";

import React, { useEffect } from 'react';
import { TouchableOpacity } from 'react-native';
import { createStyleSheet, useStyles } from 'react-native-unistyles';
import Animated, { useAnimatedStyle, useSharedValue, withTiming } from 'react-native-reanimated';
import { jsx as _jsx } from "react/jsx-runtime";
const ToggleButton = ({
  isActive,
  style,
  activeBgColor,
  inactiveBgColor,
  exInnerStyle,
  ...props
}) => {
  const {
    theme,
    styles
  } = useStyles(stylesheet);
  activeBgColor = activeBgColor || theme.adaptbyte.colors.button.primary;
  inactiveBgColor = inactiveBgColor || theme.adaptbyte.colors.grayBorder;

  // Shared value for X translation
  const translateX = useSharedValue(6);
  useEffect(() => {
    translateX.value = withTiming(isActive ? 10 : -9, {
      duration: 200
    });
  }, [isActive, translateX]);
  const animatedStyle = useAnimatedStyle(() => ({
    transform: [{
      translateX: translateX.value
    }]
  }));
  return /*#__PURE__*/_jsx(TouchableOpacity, {
    activeOpacity: 0.8,
    style: [{
      backgroundColor: isActive ? activeBgColor : inactiveBgColor
    }, styles.outerShape, style, styles.container],
    ...props,
    children: /*#__PURE__*/_jsx(Animated.View, {
      style: [styles.innerCircle, animatedStyle, exInnerStyle]
    })
  });
};
const stylesheet = createStyleSheet(theme => ({
  container: {
    width: theme.adaptbyte.length.length_50,
    height: theme.adaptbyte.length.length_30
  },
  outerShape: {
    borderRadius: theme.adaptbyte.borderRadius.radius_20,
    justifyContent: 'center',
    alignItems: 'center'
  },
  innerCircle: {
    width: theme.adaptbyte.length.length_20,
    height: theme.adaptbyte.length.length_20,
    borderRadius: theme.adaptbyte.borderRadius.radius_10,
    backgroundColor: theme.adaptbyte.colors.shade.white,
    position: 'absolute'
  }
}));
export default ToggleButton;
//# sourceMappingURL=ToggleButton.js.map