"use strict";

/* eslint-disable react-native/no-inline-styles */
import { View, Dimensions, Keyboard, TouchableWithoutFeedback, Modal, Platform } from 'react-native';
import React from 'react';
import { SPACING } from "../../../assets/theme.js";
import Animated, { runOnJS, useAnimatedStyle, useSharedValue, withTiming } from 'react-native-reanimated';
import { Gesture, GestureDetector, GestureHandlerRootView } from 'react-native-gesture-handler';
import AntDesign from 'react-native-vector-icons/AntDesign';
import { TouchableOpacity } from 'react-native';
import { Paragraph } from "../../atom/index.js";
import { createStyleSheet, useStyles } from 'react-native-unistyles';
import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
const {
  height
} = Dimensions.get('window');
const BottomSheet = ({
  isVisible,
  title = '',
  variant = 'closeButton',
  children,
  overlay = true,
  onClosePress,
  usingKeyboardAvoidingView = false,
  closeOnOverlayPress = true,
  titleConfig,
  style,
  customCloseIcon
}) => {
  const {
    styles
  } = useStyles(stylesheet);
  const [keyboardHeight, setKeyboardHeight] = React.useState(0);
  const [initialHeight, setInitialHeight] = React.useState(0);
  const additionalHeight = 30;
  const translateY = useSharedValue(0);
  const context = useSharedValue({
    y: 0
  });
  const MAX_HEIGHT = height - 50;
  const MAX_TRANSLATE_Y = height - MAX_HEIGHT;
  const keyboardViewHeight = Platform.select({
    ios: usingKeyboardAvoidingView ? keyboardHeight : 0,
    android: 0
  }) ?? 0;
  const gesture = Gesture.Pan().onStart(() => {
    'worklet';

    context.value = {
      y: translateY.value
    };
  }).onUpdate(event => {
    'worklet';

    translateY.value = event.translationY + context.value.y;
    translateY.value = Math.max(translateY.value, MAX_TRANSLATE_Y);
  }).onEnd(e => {
    'worklet';

    const isFastDownSwipe = e.velocityY > 1000;
    const isToBottomSwipe = height - translateY.value < 100;
    const isDownSwipe = height - e.absoluteY + 50 < initialHeight;
    // Close Modal when user fast down swipe or user half swipe down or swipe to bottom
    if (typeof onClosePress === 'function' && (isToBottomSwipe || isFastDownSwipe)) {
      return translateY.value = withTiming(height, {}, () => {
        runOnJS(onClosePress)?.();
      });
    }

    // User swipe down modal but not close it will back to initial position
    if (isDownSwipe) {
      return translateY.value = height - initialHeight;
    }
    return;
  });
  const reSheetStyle = useAnimatedStyle(() => {
    const getTransform = () => {
      let position = translateY.value;
      if (keyboardHeight > 0) {
        position -= keyboardViewHeight + additionalHeight;
      }

      // Set Max height for modal
      if (height - position > MAX_HEIGHT) {
        return MAX_TRANSLATE_Y;
      }
      return position;
    };
    return {
      transform: [{
        translateY: getTransform()
      }]
    };
  });
  const styleCloseButton = () => {
    if (keyboardViewHeight > 0) {
      return {
        paddingBottom: keyboardViewHeight + additionalHeight
      };
    }
    return {
      paddingBottom: 30
    };
  };
  const handleLayout = event => {
    const {
      height: measuredHeight
    } = event.nativeEvent.layout;
    setInitialHeight(measuredHeight + 100);
  };
  React.useEffect(() => {
    if (isVisible) {
      translateY.value = withTiming(height - initialHeight, {
        duration: 500
      });
    } else {
      translateY.value = withTiming(height, {
        duration: 500
      });
      Keyboard.dismiss();
    }
  }, [initialHeight, isVisible, translateY]);
  React.useEffect(() => {
    const onKeyboardShow = event => setKeyboardHeight(event.endCoordinates.height);
    const onKeyboardHide = () => setKeyboardHeight(0);
    const showListener = Keyboard.addListener('keyboardDidShow', onKeyboardShow);
    const hideListener = Keyboard.addListener('keyboardDidHide', onKeyboardHide);
    return () => {
      showListener.remove();
      hideListener.remove();
    };
  }, []);
  if (variant === 'normal') {
    return /*#__PURE__*/_jsx(_Fragment, {
      children: /*#__PURE__*/_jsx(GestureHandlerRootView, {
        children: /*#__PURE__*/_jsx(Modal, {
          transparent: true,
          visible: isVisible,
          animationType: "fade",
          children: /*#__PURE__*/_jsx(TouchableWithoutFeedback, {
            onPress: closeOnOverlayPress ? onClosePress : undefined,
            children: /*#__PURE__*/_jsx(View, {
              style: [styles.overlay, {
                backgroundColor: overlay ? 'rgba(0,0,0,0.3)' : 'transparent'
              }],
              children: /*#__PURE__*/_jsx(GestureDetector, {
                gesture: gesture,
                children: /*#__PURE__*/_jsx(TouchableWithoutFeedback, {
                  children: /*#__PURE__*/_jsx(Animated.View, {
                    // style={[styles.bottomSheet, { transform: [{ translateY }] }]}
                    // {...panResponder.panHandlers}
                    style: [reSheetStyle],
                    children: /*#__PURE__*/_jsxs(View, {
                      style: [styles.container, {
                        height
                      }, style],
                      children: [/*#__PURE__*/_jsx(View, {
                        style: styles.line
                      }), title && /*#__PURE__*/_jsx(Paragraph, {
                        style: {
                          marginTop: SPACING.space_8
                        },
                        text: title,
                        align: "center",
                        variant: "03",
                        weight: "bold",
                        ...titleConfig
                      }), /*#__PURE__*/_jsx(View, {
                        onLayout: handleLayout,
                        children: children
                      })]
                    })
                  })
                })
              })
            })
          })
        })
      })
    });
  } else {
    return /*#__PURE__*/_jsx(_Fragment, {
      children: /*#__PURE__*/_jsx(Modal, {
        animationType: "slide",
        transparent: true,
        visible: isVisible,
        onRequestClose: onClosePress // For Android back button
        ,
        children: /*#__PURE__*/_jsx(TouchableWithoutFeedback, {
          onPress: closeOnOverlayPress ? onClosePress : undefined,
          children: /*#__PURE__*/_jsx(View, {
            style: [styles.overlay, {
              backgroundColor: overlay ? 'rgba(0,0,0,0.3)' : 'transparent'
            }],
            children: /*#__PURE__*/_jsx(TouchableWithoutFeedback, {
              children: /*#__PURE__*/_jsxs(View, {
                style: [styles.container, style, styleCloseButton()],
                children: [variant === 'closeButton' && /*#__PURE__*/_jsxs(View, {
                  onLayout: handleLayout,
                  style: styles.header,
                  children: [/*#__PURE__*/_jsx(Paragraph, {
                    text: title,
                    variant: "03",
                    weight: "bold",
                    ...titleConfig
                  }), /*#__PURE__*/_jsx(TouchableOpacity, {
                    onPress: onClosePress,
                    children: customCloseIcon ?? /*#__PURE__*/_jsx(AntDesign, {
                      name: "close",
                      size: 20,
                      color: "black"
                    })
                  })]
                }), children]
              })
            })
          })
        })
      })
    });
  }
};

/**
 * Styles
 */
const stylesheet = createStyleSheet(theme => ({
  header: {
    flexDirection: 'row',
    justifyContent: 'space-between',
    alignItems: 'center'
  },
  closeIcon: {
    width: theme.adaptbyte.length.length_20,
    height: theme.adaptbyte.length.length_20
  },
  line: {
    width: theme.adaptbyte.length.length_32,
    height: theme.adaptbyte.length.length_4,
    flexShrink: 0,
    backgroundColor: theme.adaptbyte.colors.grayscale._300,
    alignSelf: 'center',
    borderRadius: theme.adaptbyte.borderRadius.radius_20,
    marginBottom: theme.adaptbyte.spacing.space_8
  },
  overlay: {
    flex: 1,
    justifyContent: 'flex-end'
  },
  container: {
    backgroundColor: theme.adaptbyte.colors.shade.white,
    borderTopRightRadius: theme.adaptbyte.borderRadius.radius_20,
    borderTopLeftRadius: theme.adaptbyte.borderRadius.radius_20,
    zIndex: 1,
    shadowOffset: {
      height: -theme.adaptbyte.length.length_2,
      width: 0
    },
    shadowOpacity: 0.05,
    elevation: theme.adaptbyte.length.length_10,
    shadowColor: 'rgba(0, 0, 0, 1)',
    paddingHorizontal: theme.adaptbyte.spacing.space_24,
    paddingTop: theme.adaptbyte.spacing.space_24,
    maxHeight: theme.adaptbyte.dimension.height - 50
  }
}));
export default BottomSheet;
//# sourceMappingURL=BottomSheet.js.map