"use strict";

import { View, Modal, FlatList, TouchableOpacity, TouchableWithoutFeedback } from 'react-native';
import React from 'react';
import Spacer from "../../atom/divider/Spacer.js";
import Paragraph from "../../atom/typograph/Paragraph.js";
import Icon from 'react-native-vector-icons/Feather';
import { createStyleSheet, useStyles } from 'react-native-unistyles';

/**
 * Popup List modal props
 */
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
/**
 * Popup List Modal
 * @returns {*}
 */
const PopupList = ({
  isVisible = false,
  keyName,
  listData = [],
  onSelect,
  onRequestClose,
  height = 400,
  width = 327,
  showCloseIcon = false,
  onPressClose,
  header,
  bottom,
  left,
  right,
  itemStyle
}) => {
  const {
    styles,
    theme
  } = useStyles(stylesheet);
  return /*#__PURE__*/_jsx(Modal, {
    animationType: "fade",
    transparent: true,
    visible: isVisible,
    children: /*#__PURE__*/_jsx(TouchableWithoutFeedback, {
      onPress: onRequestClose,
      children: /*#__PURE__*/_jsx(View, {
        style: styles.modalContainer,
        children: /*#__PURE__*/_jsx(TouchableWithoutFeedback, {
          children: /*#__PURE__*/_jsxs(View, {
            style: [styles.modalView, {
              height,
              width
            }],
            children: [showCloseIcon && /*#__PURE__*/_jsx(TouchableOpacity, {
              style: styles.closeBox,
              onPress: onPressClose,
              children: /*#__PURE__*/_jsx(Icon, {
                name: "x",
                size: 24,
                color: 'black'
              })
            }), showCloseIcon && /*#__PURE__*/_jsx(Spacer, {
              height: theme.adaptbyte.spacing.space_16
            }), header, header && /*#__PURE__*/_jsx(Spacer, {
              height: theme.adaptbyte.spacing.space_16
            }), listData?.length > 0 && /*#__PURE__*/_jsx(FlatList, {
              data: listData,
              ItemSeparatorComponent: /*#__PURE__*/_jsx(Spacer, {
                height: theme.adaptbyte.spacing.space_16
              }),
              keyExtractor: (item, index) => item?.id ? item?.id.toString() : index.toString(),
              initialNumToRender: 10,
              maxToRenderPerBatch: 10,
              removeClippedSubviews: true,
              getItemLayout: (_, index) => ({
                length: 50,
                // Assuming each item has a fixed height of 50
                offset: 50 * index,
                index
              }),
              renderItem: ({
                item
              }) => {
                return /*#__PURE__*/_jsxs(TouchableOpacity, {
                  style: [styles.itemView, itemStyle],
                  onPress: () => onSelect(item),
                  children: [left && left(item), /*#__PURE__*/_jsx(Paragraph, {
                    text: keyName ? item[keyName] : item.name,
                    weight: "medium",
                    variant: "01"
                  }), right && right(item)]
                });
              }
            }), bottom]
          })
        })
      })
    })
  });
};
const stylesheet = createStyleSheet(theme => ({
  closeBox: {
    justifyContent: 'center',
    alignItems: 'flex-end',
    paddingTop: theme.adaptbyte.spacing.space_16
  },
  modalContainer: {
    flex: 1,
    justifyContent: 'center',
    alignItems: 'center',
    backgroundColor: 'rgba(0,0,0,0.5)'
  },
  modalView: {
    width: 327,
    height: 400,
    backgroundColor: theme.adaptbyte.colors.primaryWhiteHex,
    borderRadius: theme.adaptbyte.borderRadius.radius_8,
    padding: theme.adaptbyte.spacing.space_16
  },
  itemView: {}
}));

/**
 * Export
 */
export default PopupList;
//# sourceMappingURL=PopupList.js.map