"use strict";

import React, { useState } from 'react';
import { TouchableOpacity, View } from 'react-native';
import { Paragraph } from "../../atom/index.js";
import { createStyleSheet, useStyles } from 'react-native-unistyles';
import { jsx as _jsx } from "react/jsx-runtime";
const TimeslotPicker = ({
  slots,
  onSelect,
  selectedSlot
}) => {
  const {
    styles,
    theme
  } = useStyles(stylesheet);
  const [currentSelection, setCurrentSelection] = useState(selectedSlot);
  const handleSelect = slot => {
    setCurrentSelection(slot);
    if (onSelect) {
      onSelect(slot);
    }
  };
  return /*#__PURE__*/_jsx(View, {
    style: styles.container,
    children: slots.map((slot, index) => /*#__PURE__*/_jsx(TouchableOpacity, {
      style: [styles.slot, currentSelection === slot && styles.selectedSlot],
      onPress: () => handleSelect(slot),
      children: /*#__PURE__*/_jsx(Paragraph, {
        text: slot,
        weight: "medium",
        color: currentSelection === slot ? theme.adaptbyte.colors.secondary.blue500 : theme.adaptbyte.colors.primaryBlackHex
      })
    }, `view ${index}`))
  });
};
const stylesheet = createStyleSheet(theme => ({
  container: {
    flexDirection: 'row',
    flexWrap: 'wrap',
    columnGap: theme.adaptbyte.spacing.space_16,
    alignSelf: 'center'
  },
  slot: {
    flex: 1,
    paddingVertical: theme.adaptbyte.spacing.space_12,
    paddingHorizontal: theme.adaptbyte.spacing.space_8,
    borderRadius: theme.adaptbyte.length.length_6,
    alignItems: 'center',
    borderWidth: 1,
    borderColor: theme.adaptbyte.colors.grayscale._200,
    backgroundColor: theme.adaptbyte.colors.primaryWhiteHex
  },
  selectedSlot: {
    backgroundColor: theme.adaptbyte.colors.secondary.lightBlue500
  },
  slotText: {
    fontSize: theme.adaptbyte.length.length_16,
    color: theme.adaptbyte.colors.shade.black
  },
  selectedSlotText: {
    color: theme.adaptbyte.colors.secondary.blue500
  }
}));
export default TimeslotPicker;
//# sourceMappingURL=TimeslotPicker.js.map