"use strict";

import React from 'react';
import { StatusBar, View, Platform, KeyboardAvoidingView, ScrollView } from 'react-native';
import { SafeAreaProvider, SafeAreaView } from 'react-native-safe-area-context';
import { Header } from "../../atom/index.js";
import { SPACING } from "../../../assets/theme.js";
import { createStyleSheet, useStyles } from 'react-native-unistyles';
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
const statusBarHeight = StatusBar.currentHeight ?? 0;
/**
 * Container prop
 *
 * @interface ContainerProps
 * @typedef {ContainerProps}
 * @extends {SafeAreaViewProps}
 */

/**
 * Container
 *
 * @param {ContainerProps} param0
 * @param {*} param0.children
 * @param {*} param0.style
 * @param {StatusBarStyle} [param0.barStyle="default"]
 * @param {ColorValue} [param0.barBackgroundColor="transparent"]
 * @returns {*}
 */
const Container = ({
  children,
  style,
  barStyle = 'dark-content',
  barBackgroundColor,
  isKeyboardAvoiding = false,
  backgroundColor,
  edges = ['top', 'bottom'],
  barHidden = false,
  FooterComponent,
  headerConfig = {},
  exContentStyle,
  isHeader
}) => {
  const {
    styles,
    theme
  } = useStyles(stylesheet);
  backgroundColor = backgroundColor ?? theme.adaptbyte.colors.primaryWhiteHex;
  barBackgroundColor = barBackgroundColor ?? theme.adaptbyte.colors.primaryWhiteHex;
  return /*#__PURE__*/_jsx(SafeAreaProvider, {
    children: /*#__PURE__*/_jsxs(SafeAreaView, {
      style: [style, styles.container, {
        backgroundColor: barBackgroundColor
      }],
      edges: edges,
      children: [/*#__PURE__*/_jsx(StatusBar, {
        translucent: true,
        backgroundColor: barBackgroundColor,
        barStyle: barStyle,
        hidden: barHidden
      }), isHeader && /*#__PURE__*/_jsx(Header, {
        ...headerConfig
      }), isKeyboardAvoiding ? /*#__PURE__*/_jsx(KeyboardAvoidingView, {
        style: [styles.wrapper, exContentStyle, {
          backgroundColor
        }],
        enabled: isKeyboardAvoiding,
        behavior: Platform.OS === 'ios' ? 'padding' : 'height',
        keyboardVerticalOffset: Platform.OS === 'ios' ? statusBarHeight + SPACING.space_12 : 0,
        children: /*#__PURE__*/_jsx(ScrollView, {
          showsVerticalScrollIndicator: false,
          contentContainerStyle: styles.scrollView,
          children: children
        })
      }) : /*#__PURE__*/_jsx(View, {
        style: [styles.wrapper, exContentStyle, {
          backgroundColor
        }],
        children: children
      }), FooterComponent && /*#__PURE__*/_jsx(View, {
        style: {
          backgroundColor
        },
        children: typeof FooterComponent === 'function' ? /*#__PURE__*/_jsx(FooterComponent, {}) : FooterComponent
      })]
    })
  });
};

/**
 * Stylesheet
 *
 * @type {*}
 */
const stylesheet = createStyleSheet(theme => ({
  container: {
    flexGrow: 1
  },
  wrapper: {
    paddingTop: theme.adaptbyte.spacing.container.space_top,
    paddingBottom: theme.adaptbyte.spacing.container.space_bottom,
    paddingHorizontal: theme.adaptbyte.spacing.container.space_horizontal,
    flex: 1
  },
  scrollView: {
    flexGrow: 1
  }
}));

/**
 * Export container
 */
export default Container;
//# sourceMappingURL=Container.js.map