import { type ColorValue, type StyleProp, type TextStyle, type TouchableOpacityProps, type ViewStyle } from 'react-native';
import { type DimensionValue, type TextInputProps } from 'react-native';
import type { ParagraphProps } from './text.interfaces';
import type { ReactNode } from 'react';
import type { BottomSheetProps, PopupModalProps } from './modal.interfaces';
export interface InputProps extends TextInputProps {
    label?: string;
    errorText?: string;
    helperText?: string;
    isPassword?: boolean;
    variant?: 'transparent' | 'primary' | 'secondary';
    rightIcon?: React.ReactNode;
    leftIcon?: React.ReactNode;
    disabled?: boolean;
    outputRangeSize?: number;
    multiline?: boolean;
    iIHeight?: DimensionValue;
    type?: 'normal' | 'table';
    width?: number;
    isPressable?: boolean;
    exLabelStyle?: StyleProp<TextStyle>;
    exTextInputStyle?: StyleProp<TextStyle>;
    exContainerStyle?: StyleProp<ViewStyle>;
    eyeIconColor?: ColorValue;
    alertErrorIcon?: ReactNode;
    onPress?: () => void;
}
export interface InputDateProps extends InputProps {
    defaultBottomSheetVisible?: boolean;
    dateValue?: string;
    title: string;
    config: DateBottomSheetProps;
}
export interface DateBottomSheetProps {
    onSelectDate?: (date?: string) => void;
    onSelectTimeslot?: (date?: string) => void;
    selectedDate?: string;
    isUsePickerDate?: boolean;
    isUseTimeSlot?: boolean;
    selectedTimeSlot?: string;
    calendarConfig?: {
        minDate?: string;
        maxDate?: string;
    };
    timeslotConfig?: {
        slots: string[];
    };
    submitText: string;
    onSubmit?: () => void;
}
export interface InputSelectProps extends InputProps {
    onSelect: (val: any) => void;
    listData: Array<{
        name: string;
        [key: string]: any;
    }>;
    defaultOptionVisible?: boolean;
    modalType?: 'popup' | 'bottomsheet';
    modalTitle?: string;
    renderItem?: (item: {
        name: string;
        [key: string]: any;
    }) => ReactNode;
    bottomsheetConfig?: BottomSheetProps;
    popupModalConfig?: PopupModalProps;
    titleConfig?: ParagraphProps;
    exItemsContainerStyle?: StyleProp<ViewStyle>;
}
export interface InputOtpProps {
    exInputStyle?: StyleProp<TextStyle>;
    otpLength?: number;
    defaultOtp?: string[];
    onChangeText?: (otp: string) => void;
    style?: StyleProp<ViewStyle>;
    errorText?: string;
    errorIcon?: ReactNode;
}
export interface InputPhoneNumberProps extends InputProps {
    onChangeText?: (phoneNumber: string) => void;
    onBlur?: (optional?: {
        [key: string]: any;
    }) => void;
    countryImg?: ReactNode;
    onPressCountry?: () => void;
    chevronDownColor?: string;
    phoneCodeConfig?: Partial<ParagraphProps>;
    phoneNumberRegex?: RegExp;
    isArrowDown?: boolean;
}
export interface CheckboxProps extends TouchableOpacityProps {
    isChecked: boolean;
    customCheckedIcon?: React.ReactNode;
    width?: number;
    height?: number;
    activeBgColor?: ColorValue;
    exCheckedStyle?: StyleProp<ViewStyle>;
    exUnCheckedStyle?: StyleProp<ViewStyle>;
}
export interface ToggleButtonProps extends TouchableOpacityProps {
    isActive: boolean;
    style?: StyleProp<ViewStyle>;
    activeBgColor?: ColorValue;
    inactiveBgColor?: ColorValue;
    exInnerStyle?: StyleProp<ViewStyle>;
}
//# sourceMappingURL=form.interfaces.d.ts.map