import { View, type ColorValue, type FlexStyle } from 'react-native';

/**
 * Line Props
 */
interface LineProps {
  thickness?: number;
  color?: ColorValue;
  length?: FlexStyle['width'];
  orientation?: 'horizontal' | 'vertical';
  margin?: number;
}

/**
 * This component can be used to render or vertical lines with customized thickness (height, width)
 * @param {LineProps} props
 * @returns
 */
const Line = ({
  thickness = 1,
  color = '#D3D3D3',
  length = '100%',
  orientation = 'horizontal',
  margin = 0,
}: LineProps) => {
  return (
    <View
      style={[
        {
          height: orientation === 'horizontal' ? thickness : length,
          backgroundColor: color,
          width: orientation === 'horizontal' ? length : thickness,
        },
        orientation === 'horizontal' && { marginHorizontal: margin },
        orientation === 'vertical' && { marginVertical: margin },
      ]}
    />
  );
};

/**
 * Export
 */
export default Line;
