import { TouchableOpacity, View } from 'react-native';
import Icon from 'react-native-vector-icons/Feather';
import Spacer from '../divider/Spacer';
import { SPACING } from '../../../assets/theme';
import Heading from '../typograph/Heading';
import { Line } from '../divider';
import type { HeaderProps } from '../../../interfaces';
import { createStyleSheet, useStyles } from 'react-native-unistyles';

const Header = ({
  headerMiddle,
  headerText,
  underline = false,
  btnBackColor,
  onBackPress,
  style,
  rightContent,
  titleConfig,
}: HeaderProps) => {
  const { styles, theme } = useStyles(stylesheet);
  btnBackColor = btnBackColor || theme.adaptbyte.colors.shade.black;
  const navigationBack = () => {
    onBackPress?.();
  };

  return (
    <>
      <View style={[styles.container, style]}>
        {onBackPress ? (
          <TouchableOpacity
            onPress={navigationBack}
            style={[styles.leftContainer]}
          >
            <Icon
              name={'arrow-left'}
              size={theme.adaptbyte.length.length_24}
              color={btnBackColor}
            />
          </TouchableOpacity>
        ) : (
          <Spacer flex={1} />
        )}
        {headerText && (
          <View style={{ marginLeft: SPACING.space_16 }}>
            <Heading
              text={headerText}
              variant="h6"
              weight="bold"
              align="center"
              {...titleConfig}
            />
          </View>
        )}
        <Spacer width={SPACING.space_16} />
        <View style={styles.centerContainer}>
          {typeof headerMiddle === 'string' ? (
            <Heading
              color={theme.adaptbyte.colors.grayscale._703}
              text={headerMiddle}
              variant="h6-small"
              weight="bold"
              align="center"
              style={{
                marginLeft: -theme.adaptbyte.spacing.space_32,
              }}
              {...titleConfig}
            />
          ) : (
            headerMiddle
          )}
        </View>
        {rightContent && (
          <View style={styles.rightContainer}>{rightContent}</View>
        )}
      </View>
      {underline && (
        <View>
          <Line />
        </View>
      )}
    </>
  );
};

const stylesheet = createStyleSheet((theme) => ({
  container: {
    flexDirection: 'row',
    alignItems: 'center',
    paddingVertical: theme.adaptbyte.spacing.space_16,
    paddingHorizontal: theme.adaptbyte.spacing.space_16,
  },
  leftContainer: {},
  rightContainer: {
    right: 0,
  },
  centerContainer: {
    flex: 8,
    width: '100%',
    justifyContent: 'center',
    alignItems: 'center',
  },
  rounded: {
    height: theme.adaptbyte.length.length_60,
    width: theme.adaptbyte.length.length_60,
    borderRadius: theme.adaptbyte.borderRadius.radius_50,
    justifyContent: 'center',
    alignItems: 'center',
  },
  headerText: {
    marginLeft: theme.adaptbyte.spacing.space_8,
    fontSize: theme.adaptbyte.typography.paragraph['text-02'].fontSize,
    color: theme.adaptbyte.colors.shade.black,
  },
  underline: {
    paddingHorizontal: theme.adaptbyte.spacing.space_16,
  },
}));

export default Header;
