import React, { type LegacyRef } from 'react';
import { Text } from 'react-native';
import type { DisplayProps } from '../../../interfaces';
import { createStyleSheet, useStyles } from 'react-native-unistyles';

const Display = React.forwardRef(
  (
    {
      variant = '01',
      weight = 'light',
      text,
      color,
      align = 'left',
      style,
      fontStyle = 'normal',
      fontSize,
      ...props
    }: DisplayProps,
    ref: LegacyRef<Text>
  ) => {
    const { styles, theme } = useStyles(stylesheet);
    color = color || theme.adaptbyte.colors.shade.black;

    return (
      <Text
        ref={ref}
        style={[
          styles[variant],
          {
            fontFamily: theme.adaptbyte.font?.[fontStyle]?.[weight],
            color,
            textAlign: align,
            fontStyle,
          },
          fontSize ? { fontSize } : undefined,
          style,
        ]}
        {...props}
      >
        {text}
      </Text>
    );
  }
);

const stylesheet = createStyleSheet((theme) => ({
  /**
   * Variants
   */
  '01': theme.adaptbyte.typography.display['01'],
  '02': theme.adaptbyte.typography.display['02'],
}));

export default Display;
