import React, { forwardRef, type LegacyRef } from 'react';
import { Text } from 'react-native';
import type { HeadingProps } from '../../../interfaces';
import { createStyleSheet, useStyles } from 'react-native-unistyles';

const Heading = forwardRef(
  (
    {
      variant = 'h1',
      weight = 'light',
      text,
      color,
      align = 'left',
      style: styleOverride,
      fontStyle = 'normal',
      textDecorationLine,
      fontSize,
      ...props
    }: HeadingProps,
    ref: LegacyRef<Text>
  ) => {
    const { styles, theme } = useStyles(stylesheet);
    color = color || theme.adaptbyte.colors.shade.black;

    return (
      <Text
        ref={ref}
        style={[
          styles[variant],
          {
            fontFamily: theme.adaptbyte.font?.[fontStyle]?.[weight],
            color,
            textAlign: align,
            textDecorationLine,
            fontStyle,
          },
          fontSize ? { fontSize } : undefined,
          styleOverride,
        ]}
        {...props}
      >
        {text}
      </Text>
    );
  }
);

const stylesheet = createStyleSheet((theme) => ({
  /**
   * Variants
   */
  'h1': theme.adaptbyte.typography.heading.h1,
  'h1-small': theme.adaptbyte.typography.heading['h1-small'],
  'h2': theme.adaptbyte.typography.heading.h2,
  'h2-small': theme.adaptbyte.typography.heading['h2-small'],
  'h3': theme.adaptbyte.typography.heading.h3,
  'h3-small': theme.adaptbyte.typography.heading['h3-small'],
  'h4': theme.adaptbyte.typography.heading.h4,
  'h4-small': theme.adaptbyte.typography.heading['h4-small'],
  'h5': theme.adaptbyte.typography.heading.h5,
  'h5-small': theme.adaptbyte.typography.heading['h5-small'],
  'h6': theme.adaptbyte.typography.heading.h6,
  'h6-small': theme.adaptbyte.typography.heading['h6-small'],
}));

export default Heading;
