import React, { forwardRef, type LegacyRef } from 'react';
import { Text } from 'react-native';
import type { ParagraphProps } from '../../../interfaces';
import { createStyleSheet, useStyles } from 'react-native-unistyles';

const Paragraph = forwardRef(
  (
    {
      text,
      weight = 'light',
      color,
      variant = '01',
      align = 'left',
      textDecorationLine,
      fontStyle = 'normal',
      style: styleOverride,
      fontSize,
      ...props
    }: ParagraphProps,
    ref: LegacyRef<Text>
  ) => {
    const { styles, theme } = useStyles(stylesheet);
    color = color || theme.adaptbyte.colors.shade.black;

    return (
      <Text
        ref={ref}
        style={[
          styles[`text-${variant}`],
          {
            fontFamily: theme.adaptbyte.font?.[fontStyle]?.[weight],
            color,
            textAlign: align,
            textDecorationLine,
            fontStyle,
          },
          fontSize ? { fontSize } : undefined,
          styleOverride,
        ]}
        {...props}
      >
        {text}
      </Text>
    );
  }
);

const stylesheet = createStyleSheet((theme) => ({
  /**
   * Variants
   */
  'text-00': theme.adaptbyte.typography.paragraph['text-00'],
  'text-01': theme.adaptbyte.typography.paragraph['text-01'],
  'text-02': theme.adaptbyte.typography.paragraph['text-02'],
  'text-03': theme.adaptbyte.typography.paragraph['text-03'],
  'text-Subheading': theme.adaptbyte.typography.paragraph['text-Subheading'],
  'text-Caption': theme.adaptbyte.typography.paragraph['text-Caption'],
  'text-Footer': theme.adaptbyte.typography.paragraph['text-Footer'],
  'text-Tags': theme.adaptbyte.typography.paragraph['text-Tags'],
  'text-undefined': {},
}));

export default Paragraph;
