import React, { forwardRef, type LegacyRef } from 'react';
import { Text } from 'react-native';
import type { SmallProps } from '../../../interfaces';
import { createStyleSheet, useStyles } from 'react-native-unistyles';

const Small = forwardRef(
  (
    {
      text,
      weight = 'light',
      color,
      variant = 's1',
      align = 'left',
      textDecorationLine,
      fontStyle = 'normal',
      style: styleOverride,
      fontSize,
      ...props
    }: SmallProps,
    ref: LegacyRef<Text>
  ) => {
    const { styles, theme } = useStyles(stylesheet);
    color = color || theme.adaptbyte.colors.shade.black;

    return (
      <Text
        ref={ref}
        style={[
          styles[variant],
          {
            fontFamily: theme.adaptbyte.font?.[fontStyle]?.[weight],
            color,
            textAlign: align,
            textDecorationLine,
            fontStyle,
          },
          fontSize ? { fontSize } : undefined,
          styleOverride,
        ]}
        {...props}
      >
        {text}
      </Text>
    );
  }
);

const stylesheet = createStyleSheet((theme) => ({
  /**
   * Variants
   */
  s1: theme.adaptbyte.typography.small.s1,
  s2: theme.adaptbyte.typography.small.s2,
  s3: theme.adaptbyte.typography.small.s3,
  undefined: {},
}));

export default Small;
