import React from 'react';
import { TouchableOpacity } from 'react-native';
import Icon from 'react-native-vector-icons/FontAwesome5';
import { createStyleSheet, useStyles } from 'react-native-unistyles';
import type { CheckboxProps } from '../../../interfaces';

const Checkbox = ({
  isChecked,
  customCheckedIcon,
  width = 18,
  height = 18,
  exCheckedStyle,
  exUnCheckedStyle,
  activeBgColor,
  ...props
}: CheckboxProps) => {
  const { theme, styles } = useStyles(stylesheet);
  width = width || theme.adaptbyte.length.length_18;
  height = height || theme.adaptbyte.length.length_18;
  activeBgColor = activeBgColor || theme.adaptbyte.colors.button.primary;

  return (
    <>
      {isChecked ? (
        <TouchableOpacity
          style={[
            styles.container,
            styles.checked,
            { width, height, backgroundColor: activeBgColor },
            exCheckedStyle,
          ]}
          {...props}
        >
          {customCheckedIcon ? (
            customCheckedIcon
          ) : (
            <Icon
              name="check"
              size={12}
              color={theme.adaptbyte.colors.shade.white}
            />
          )}
        </TouchableOpacity>
      ) : (
        <TouchableOpacity
          style={[
            styles.container,
            styles.unChecked,
            { width, height },
            exUnCheckedStyle,
          ]}
          {...props}
        />
      )}
    </>
  );
};

const stylesheet = createStyleSheet((theme) => ({
  container: {
    borderRadius: 5,
  },
  checked: {
    justifyContent: 'center',
    alignItems: 'center',
  },
  unChecked: {
    backgroundColor: theme.adaptbyte.colors.primaryWhiteHex,
    borderColor: theme.adaptbyte.colors.grayBorder,
    borderWidth: 1,
  },
}));

export default Checkbox;
