import { createStyleSheet, type UnistylesTheme } from 'react-native-unistyles';

export const inputVariantStyle = (theme: UnistylesTheme) => ({
  transparent: {
    container: {
      borderColor: theme.adaptbyte.colors.input.transparent.borderColor,
      borderWidth: 1,
      backgroundColor: theme.adaptbyte.colors.input.transparent.backgroundColor,
      borderRadius: 8,
    },
    input: {
      color: theme.adaptbyte.colors.input.transparent.textColor,
    },
    label: {
      color: theme.adaptbyte.colors.input.transparent.labelColor,
    },
    errorContainer: {
      borderColor: theme.adaptbyte.colors.input.transparent.errorBorderColor,
      backgroundColor:
        theme.adaptbyte.colors.input.transparent.errorBackgroundColor,
    },
    errorDisabledContainer: {
      borderColor: theme.adaptbyte.colors.error._700,
    },
    disabledContainer: {},
    disabledInput: {
      color: theme.adaptbyte.colors.input.transparent.disabledTextColor,
    },
  },
  primary: {
    container: {
      borderColor: theme.adaptbyte.colors.input.primary.borderColor,
      backgroundColor: theme.adaptbyte.colors.input.primary.backgroundColor,
      borderWidth: 1,
      borderRadius: 8,
    },
    input: {
      color: theme.adaptbyte.colors.input.primary.textColor,
    },
    label: {
      color: theme.adaptbyte.colors.input.primary.labelColor,
    },
    errorContainer: {
      borderColor: theme.adaptbyte.colors.input.primary.errorBorderColor,
      backgroundColor:
        theme.adaptbyte.colors.input.primary.errorBackgroundColor,
    },
    errorDisabledContainer: {
      borderColor: theme.adaptbyte.colors.error._700,
      backgroundColor: theme.adaptbyte.colors.lightDanger,
    },
    disabledContainer: {
      backgroundColor: theme.adaptbyte.colors.grayscale._50,
    },
    disabledInput: {
      color: theme.adaptbyte.colors.input.primary.disabledTextColor,
    },
  },
  secondary: {
    container: {
      borderColor: theme.adaptbyte.colors.input.secondary.borderColor,
      backgroundColor: theme.adaptbyte.colors.input.secondary.backgroundColor,
      borderWidth: 1,
      borderRadius: 8,
    },
    input: {
      color: theme.adaptbyte.colors.input.secondary.textColor,
    },
    label: {
      color: theme.adaptbyte.colors.input.secondary.labelColor,
    },
    errorContainer: {
      borderColor: theme.adaptbyte.colors.input.secondary.errorBorderColor,
      backgroundColor:
        theme.adaptbyte.colors.input.secondary.errorBackgroundColor,
    },
    errorDisabledContainer: {
      backgroundColor: theme.adaptbyte.colors.error._200,
    },
    disabledContainer: {
      backgroundColor: theme.adaptbyte.colors.grayscale._50,
    },
    disabledInput: {
      color: theme.adaptbyte.colors.input.secondary.disabledTextColor,
    },
  },
});

export const inputStyles = createStyleSheet((theme) => ({
  container: {
    paddingVertical: theme.adaptbyte.spacing.space_8,
    paddingHorizontal: theme.adaptbyte.spacing.space_16,
    height: theme.adaptbyte.length.length_57,
    overflow: 'hidden',
    minHeight: theme.adaptbyte.length.length_57,
  },
  label: {
    position: 'absolute',
    left: 0,
    top: theme.adaptbyte.length.length_32,
    fontSize: theme.adaptbyte.length.length_12,
    lineHeight: theme.adaptbyte.length.length_16,
  },
  input: {
    padding: 0,
    height: theme.adaptbyte.length.length_18,
    minHeight: theme.adaptbyte.length.length_18,
    lineHeight: theme.adaptbyte.length.length_18,
    fontSize: theme.adaptbyte.length.length_14,
  },
  innerInputContainer: {
    flexDirection: 'row',
  },
  innerInput: {
    width: '95%',
    color: theme.adaptbyte.colors.primaryWhiteHex,
  },
  iconContainer: {
    justifyContent: 'center',
    alignItems: 'flex-end',
  },
  helperContainer: {
    flexDirection: 'row',
    paddingHorizontal: theme.adaptbyte.spacing.space_8,
    marginTop: theme.adaptbyte.spacing.space_8,
  },
  helperIcon: {
    justifyContent: 'center',
    alignItems: 'flex-start',
    marginRight: theme.adaptbyte.spacing.space_8,
  },
  helperMessage: {
    justifyContent: 'center',
    alignItems: 'flex-start',
  },
  leftIconContainer: { justifyContent: 'center', alignItems: 'center' },
  rightIconContainer: { justifyContent: 'center', alignItems: 'center' },
}));
