import { View, Image, TouchableOpacity } from 'react-native';
import React, { useState } from 'react';
import FontAwesome5 from 'react-native-vector-icons/FontAwesome';
import { LENGTH, SPACING } from '../../../assets/theme';
import { inputVariantStyle } from './Input.style';
import type { InputPhoneNumberProps } from '../../../interfaces';
import { Line, Paragraph, Spacer } from '../../atom';
import { Input } from '../form';
import { createStyleSheet, useStyles } from 'react-native-unistyles';
/**
 *
 * @param {InputPhoneNumberProps}
 * @returns
 */

const InputPhoneNumber: React.FC<InputPhoneNumberProps> = ({
  onChangeText,
  onBlur,
  onPressCountry,
  chevronDownColor,
  phoneNumberRegex = /^[1-9][0-9]{7,9}$/,
  countryImg = (
    <Image
      style={{ width: LENGTH.length_24, height: LENGTH.length_16 }}
      source={require('../../../assets/image/webp/malaysia_flag.webp')}
    />
  ),
  phoneCodeConfig = {
    text: '+60',
  },
  placeholder = 'Phone Number',
  exTextInputStyle = {},
  variant = 'transparent',
  style = {},
  isArrowDown,
  maxLength = 13,
  ...props
}) => {
  const [phoneNumber, setPhoneNumber] = useState<string>('');
  const { styles, theme } = useStyles(stylesheet);

  const leftIcon = (
    <View style={styles.leftIconContainer}>
      <TouchableOpacity
        style={styles.leftIconButton}
        onPress={onPressCountry}
        disabled={true}
      >
        {countryImg}
        <Spacer width={SPACING.space_8} />
        {isArrowDown && (
          <>
            <FontAwesome5
              name="chevron-down"
              color={
                chevronDownColor ??
                inputVariantStyle(theme)?.[variant]?.input?.color
              }
            />
          </>
        )}
        <Spacer width={SPACING.space_12} />
      </TouchableOpacity>
      <Line orientation="vertical" length={LENGTH.length_42} />
      <Spacer width={SPACING.space_12} />
      <Paragraph
        variant="01"
        weight="extrabold"
        text={phoneCodeConfig?.text as string}
        color={
          phoneCodeConfig?.color ??
          inputVariantStyle(theme)?.[variant]?.input?.color
        }
        {...phoneCodeConfig}
      />
      <Spacer width={SPACING.space_8} />
    </View>
  );

  const onChangePhoneNumber = (text: string) => {
    setPhoneNumber(text);
    onChangeText?.(text);
  };

  const onPhoneNumberBlur = () => {
    if (!phoneNumberRegex.test(phoneNumber)) {
      onBlur?.({ error: 'invalidPhone' });
    } else {
      onBlur?.();
    }
  };

  return (
    <Input
      type="table"
      keyboardType={'phone-pad'}
      style={[styles.style, style]}
      maxLength={maxLength}
      onChangeText={onChangePhoneNumber}
      onBlur={onPhoneNumberBlur}
      leftIcon={leftIcon}
      placeholder={placeholder}
      exTextInputStyle={[styles.exTextInputStyle, exTextInputStyle]}
      variant={variant}
      {...props}
    />
  );
};

const stylesheet = createStyleSheet(() => ({
  leftIconContainer: {
    flexDirection: 'row',
    alignItems: 'center',
    height: '100%',
  },
  leftIconButton: {
    height: '100%',
    alignItems: 'center',
    flexDirection: 'row',
  },
  style: { justifyContent: 'center' },
  exTextInputStyle: { left: 0 },
}));

export default InputPhoneNumber;
