import React, { useEffect, useState } from 'react';
import { Input } from '../form';
import FontAwesome5Icon from 'react-native-vector-icons/FontAwesome5';
import { BottomSheet, PopupModal } from '../modals';
import type { InputSelectProps } from '../../../interfaces/form.interfaces';
import { useStyles } from 'react-native-unistyles';
import { View } from 'react-native';
import { Typography } from '../../atom';

/**
 * Component prop
 *
 * @interface InputSelectProps
 * @typedef {InputSelectProps}
 * @extends {InputProps}
 */

/**
 * Component
 * @param param0
 * @returns
 */

function InputSelect({
  onSelect,
  listData = [],
  value,
  defaultOptionVisible,
  modalType,
  renderItem,
  modalTitle,
  titleConfig,
  bottomsheetConfig,
  popupModalConfig,
  exItemsContainerStyle,
  ...props
}: InputSelectProps) {
  const [isOptionVisible, setOptionVisible] = useState(false);
  const { theme } = useStyles();

  useEffect(() => {
    if (typeof defaultOptionVisible === 'boolean') {
      setOptionVisible(defaultOptionVisible);
    }
  }, [defaultOptionVisible]);

  const renderItems = () => {
    return listData?.map((item) =>
      renderItem ? (
        renderItem(item)
      ) : (
        <Typography.Paragraph
          onPress={() => {
            onSelect(item);
            setOptionVisible(false);
          }}
          weight="medium"
          style={{ marginBottom: theme.adaptbyte.spacing.space_20 }}
          key={item?.name}
          text={item?.name}
        />
      )
    );
  };

  return (
    <>
      <Input
        defaultValue={value}
        isPressable
        onPress={() => setOptionVisible(!isOptionVisible)}
        rightIcon={
          <FontAwesome5Icon
            name="chevron-down"
            color={theme.adaptbyte.colors.grayscale._500}
            size={theme.adaptbyte.length.length_20}
          />
        }
        {...props}
      />
      {modalType === 'bottomsheet' ? (
        <BottomSheet
          onClosePress={() => setOptionVisible(false)}
          title={modalTitle}
          isVisible={isOptionVisible}
          titleConfig={titleConfig}
          {...bottomsheetConfig}
        >
          <View
            style={[
              { marginTop: theme.adaptbyte.spacing.space_30 },
              exItemsContainerStyle,
            ]}
          >
            {renderItems()}
          </View>
        </BottomSheet>
      ) : (
        <PopupModal
          onBackdropPress={() => setOptionVisible(false)}
          isVisible={isOptionVisible}
          {...popupModalConfig}
        >
          {!!modalTitle && (
            <Typography.Paragraph
              variant="03"
              text={modalTitle}
              weight="bold"
              {...titleConfig}
            />
          )}
          <View
            style={[
              { marginTop: theme.adaptbyte.spacing.space_30 },
              exItemsContainerStyle,
            ]}
          >
            {renderItems()}
          </View>
        </PopupModal>
      )}
    </>
  );
}

export default InputSelect;
