import React from 'react';
import {
  View,
  Modal,
  KeyboardAvoidingView,
  TouchableWithoutFeedback,
} from 'react-native';
import { BORDERRADIUS, SPACING } from '../../../assets/theme';
import { Platform } from 'react-native';
import type { PopupModalProps } from '../../../interfaces';
import { createStyleSheet, useStyles } from 'react-native-unistyles';

const PopupModal = ({
  isVisible = false,
  usingKeyboardAvoidingView = false,
  children,
  width = 343,
  padding = SPACING.space_16,
  backgroundColor,
  styleModal,
  styleModalView,
  borderRadius = BORDERRADIUS.radius_16,
  onBackdropPress,
}: PopupModalProps) => {
  const { styles, theme } = useStyles(stylesheet);
  backgroundColor = backgroundColor ?? theme.adaptbyte.colors.primaryWhiteHex;

  return (
    <Modal animationType="slide" transparent={true} visible={isVisible}>
      <TouchableWithoutFeedback
        onPress={
          typeof onBackdropPress === 'function' ? onBackdropPress : undefined
        }
      >
        <View style={[styles.modalContainer, styleModal]}>
          {usingKeyboardAvoidingView ? (
            <KeyboardAvoidingView
              behavior={Platform.OS === 'ios' ? 'padding' : 'height'}
              keyboardVerticalOffset={0} // Use the offset prop
            >
              <View
                style={[
                  styles.modalView,
                  { width, padding, backgroundColor, borderRadius },
                  styleModalView,
                ]}
              >
                <View style={{ width: '100%' }}>{children}</View>
              </View>
            </KeyboardAvoidingView>
          ) : (
            <View
              style={[
                styles.modalView,
                { width, padding, backgroundColor, borderRadius },
                styleModalView,
              ]}
            >
              <View style={{ width: '100%' }}>{children}</View>
            </View>
          )}
        </View>
      </TouchableWithoutFeedback>
    </Modal>
  );
};

/**
 * Styles
 */
const stylesheet = createStyleSheet((theme) => ({
  modalContainer: {
    flex: 1,
    justifyContent: 'center',
    alignItems: 'center',
    backgroundColor: theme.adaptbyte.colors.popupBackgroundRGBA,
  },
  modalView: {
    alignItems: 'center',
    justifyContent: 'center',
  },
}));

/**
 * Export
 */
export default PopupModal;
