import { useState } from 'react';
import { Calendar, type CalendarProps } from 'react-native-calendars';
import { createStyleSheet, useStyles } from 'react-native-unistyles';

export interface CalendarPickerProps extends CalendarProps {
  onDateChange?: (date: string) => void;
  dateValue: string;
  minDate?: string;
}

const CalendarPicker = ({
  dateValue,
  onDateChange,
  minDate,
  ...props
}: CalendarPickerProps) => {
  const { styles, theme } = useStyles(stylesheet);
  const [selectedDate, setSelectedDate] = useState(dateValue);

  const handleDayPress = (day: any) => {
    const date = day.dateString;
    setSelectedDate(date);
    onDateChange && onDateChange(date); // Notify the parent component of the selected date
  };

  return (
    <>
      <Calendar
        style={styles.container}
        onDayPress={handleDayPress}
        markingType={'custom'}
        minDate={minDate}
        theme={{
          textDayHeaderFontSize: 14,
          textDayHeaderFontWeight: '700',
          textMonthFontWeight: '700',
          dayTextColor: '#030303',
          arrowColor: '#030303',
        }}
        markedDates={{
          [selectedDate]: {
            customStyles: {
              container: {
                backgroundColor: theme.adaptbyte.colors.primary._100,
              },
              text: {
                color: theme.adaptbyte.colors.primary._500,
                fontFamily: theme.adaptbyte.font.normal.bold,
              },
            },
          },
        }}
        hideExtraDays={true}
        {...props}
      />
    </>
  );
};

const stylesheet = createStyleSheet(() => ({
  container: {
    marginHorizontal: -15,
  },
}));

export default CalendarPicker;
