import React, { useState } from 'react';
import { TouchableOpacity, View } from 'react-native';
import { Paragraph } from '../../atom';
import { createStyleSheet, useStyles } from 'react-native-unistyles';

interface TimeslotPickerProps {
  slots: string[];
  onSelect?: (selectedSlot: string) => void;
  selectedSlot?: string;
}

const TimeslotPicker: React.FC<TimeslotPickerProps> = ({
  slots,
  onSelect,
  selectedSlot,
}) => {
  const { styles, theme } = useStyles(stylesheet);
  const [currentSelection, setCurrentSelection] = useState(selectedSlot);

  const handleSelect = (slot: string) => {
    setCurrentSelection(slot);
    if (onSelect) {
      onSelect(slot);
    }
  };

  return (
    <View style={styles.container}>
      {slots.map((slot, index) => (
        <TouchableOpacity
          key={`view ${index}`}
          style={[
            styles.slot,
            currentSelection === slot && styles.selectedSlot,
          ]}
          onPress={() => handleSelect(slot)}
        >
          <Paragraph
            text={slot}
            weight="medium"
            color={
              currentSelection === slot
                ? theme.adaptbyte.colors.secondary.blue500
                : theme.adaptbyte.colors.primaryBlackHex
            }
          />
        </TouchableOpacity>
      ))}
    </View>
  );
};

const stylesheet = createStyleSheet((theme) => ({
  container: {
    flexDirection: 'row',
    flexWrap: 'wrap',
    columnGap: theme.adaptbyte.spacing.space_16,
    alignSelf: 'center',
  },
  slot: {
    flex: 1,
    paddingVertical: theme.adaptbyte.spacing.space_12,
    paddingHorizontal: theme.adaptbyte.spacing.space_8,
    borderRadius: theme.adaptbyte.length.length_6,
    alignItems: 'center',
    borderWidth: 1,
    borderColor: theme.adaptbyte.colors.grayscale._200,
    backgroundColor: theme.adaptbyte.colors.primaryWhiteHex,
  },
  selectedSlot: {
    backgroundColor: theme.adaptbyte.colors.secondary.lightBlue500,
  },
  slotText: {
    fontSize: theme.adaptbyte.length.length_16,
    color: theme.adaptbyte.colors.shade.black,
  },
  selectedSlotText: {
    color: theme.adaptbyte.colors.secondary.blue500,
  },
}));

export default TimeslotPicker;
